@@ -43,6 +43,29 @@ class Util {
     private static final Class<?>[] EMPTY_CLASS_ARRAY = new Class<?>[0];
     private static final Object[] EMPTY_OBJECT_ARRAY = new Object[0];
 
+    private static final boolean IS_SECURITY_ENABLED = (System.getSecurityManager() != null);
+
+    private static final boolean GET_CLASSLOADER_USE_PRIVILEGED;
+
+    static {
+        if (IS_SECURITY_ENABLED) {
+            // Defaults to using a privileged block
+            // When running on Tomcat this will be set to false in
+            // $CATALINA_BASE/conf/catalina.properties
+            String value = AccessController.doPrivileged(new PrivilegedAction<String>() {
+                @Override
+                public String run() {
+                    return System.getProperty("org.apache.el.GET_CLASSLOADER_USE_PRIVILEGED", "true");
+                }
+            });
+            GET_CLASSLOADER_USE_PRIVILEGED = Boolean.parseBoolean(value);
+        } else {
+            // No security manager - no need to use a privileged block.
+            GET_CLASSLOADER_USE_PRIVILEGED = false;
+        }
+    }
+
+
     /**
      * Checks whether the supplied Throwable is one that needs to be
      * rethrown and swallows all others.
@@ -148,7 +171,7 @@ class Util {
         private final int hash;
         private final WeakReference<ClassLoader> ref;
 
-        public CacheKey(ClassLoader key) {
+        CacheKey(ClassLoader key) {
             hash = key.hashCode();
             ref = new WeakReference<>(key);
         }
@@ -178,7 +201,7 @@ class Util {
         private final ReadWriteLock lock = new ReentrantReadWriteLock();
         private WeakReference<ExpressionFactory> ref;
 
-        public CacheValue() {
+        CacheValue() {
         }
 
         public ReadWriteLock getLock() {
@@ -383,7 +406,7 @@ class Util {
     }
 
 
-    private static final String paramString(Class<?>[] types) {
+    private static String paramString(Class<?>[] types) {
         if (types != null) {
             StringBuilder sb = new StringBuilder();
             for (Class<?> type : types) {
@@ -649,7 +672,7 @@ class Util {
 
     static ClassLoader getContextClassLoader() {
         ClassLoader tccl;
-        if (System.getSecurityManager() != null) {
+        if (IS_SECURITY_ENABLED && GET_CLASSLOADER_USE_PRIVILEGED) {
             PrivilegedAction<ClassLoader> pa = new PrivilegedGetTccl();
             tccl = AccessController.doPrivileged(pa);
         } else {
@@ -690,7 +713,7 @@ class Util {
     private static class MethodWrapper extends Wrapper<Method> {
         private final Method m;
 
-        public MethodWrapper(Method m) {
+        MethodWrapper(Method m) {
             this.m = m;
         }
 
@@ -718,7 +741,7 @@ class Util {
     private static class ConstructorWrapper extends Wrapper<Constructor<?>> {
         private final Constructor<?> c;
 
-        public ConstructorWrapper(Constructor<?> c) {
+        ConstructorWrapper(Constructor<?> c) {
             this.c = c;
         }
 
@@ -756,7 +779,7 @@ class Util {
         private final int varArgsCount;
         private final boolean bridge;
 
-        public MatchResult(boolean varArgs, int exactCount, int assignableCount, int coercibleCount, int varArgsCount,
+        MatchResult(boolean varArgs, int exactCount, int assignableCount, int coercibleCount, int varArgsCount,
                 boolean bridge) {
             this.varArgs = varArgs;
             this.exactCount = exactCount;
