@@ -5,216 +5,219 @@
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * 
+ *
  *      http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
-
 package org.apache.catalina.connector;
 
 import java.io.BufferedReader;
 import java.io.IOException;
 import java.security.AccessController;
 import java.security.PrivilegedAction;
+import java.util.Collection;
 import java.util.Enumeration;
 import java.util.Locale;
 import java.util.Map;
 
+import javax.servlet.AsyncContext;
+import javax.servlet.DispatcherType;
 import javax.servlet.RequestDispatcher;
+import javax.servlet.ServletContext;
+import javax.servlet.ServletException;
 import javax.servlet.ServletInputStream;
+import javax.servlet.ServletRequest;
+import javax.servlet.ServletResponse;
 import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServletRequest;
+import javax.servlet.http.HttpServletResponse;
 import javax.servlet.http.HttpSession;
+import javax.servlet.http.HttpUpgradeHandler;
+import javax.servlet.http.Part;
 
 import org.apache.catalina.Globals;
-import org.apache.catalina.util.StringManager;
-
-
+import org.apache.catalina.core.ApplicationMappingImpl;
+import org.apache.catalina.core.ApplicationPushBuilder;
 import org.apache.catalina.security.SecurityUtil;
+import org.apache.tomcat.util.res.StringManager;
 
 /**
- * Facade class that wraps a Coyote request object.  
+ * Facade class that wraps a Coyote request object.
  * All methods are delegated to the wrapped request.
  *
  * @author Craig R. McClanahan
  * @author Remy Maucherat
- * @author Jean-Francois Arcand
- * @version $Revision: 750908 $ $Date: 2009-03-06 15:04:54 +0100 (Fri, 06 Mar 2009) $
  */
-
 @SuppressWarnings("deprecation")
 public class RequestFacade implements HttpServletRequest {
-        
-        
-    // ----------------------------------------------------------- DoPrivileged
-    
+
+
     private final class GetAttributePrivilegedAction
-            implements PrivilegedAction {
-        
-        public Object run() {
+            implements PrivilegedAction<Enumeration<String>> {
+
+        @Override
+        public Enumeration<String> run() {
             return request.getAttributeNames();
-        }            
+        }
     }
-     
-    
+
+
     private final class GetParameterMapPrivilegedAction
-            implements PrivilegedAction {
-        
-        public Object run() {
+            implements PrivilegedAction<Map<String,String[]>> {
+
+        @Override
+        public Map<String,String[]> run() {
             return request.getParameterMap();
-        }        
-    }    
-    
-    
+        }
+    }
+
+
     private final class GetRequestDispatcherPrivilegedAction
-            implements PrivilegedAction {
+            implements PrivilegedAction<RequestDispatcher> {
 
-        private String path;
+        private final String path;
 
-        public GetRequestDispatcherPrivilegedAction(String path){
+        GetRequestDispatcherPrivilegedAction(String path){
             this.path = path;
         }
-        
-        public Object run() {   
+
+        @Override
+        public RequestDispatcher run() {
             return request.getRequestDispatcher(path);
-        }           
-    }    
-    
-    
+        }
+    }
+
+
     private final class GetParameterPrivilegedAction
-            implements PrivilegedAction {
+            implements PrivilegedAction<String> {
 
         public String name;
 
-        public GetParameterPrivilegedAction(String name){
+        GetParameterPrivilegedAction(String name){
             this.name = name;
         }
 
-        public Object run() {       
+        @Override
+        public String run() {
             return request.getParameter(name);
-        }           
-    }    
-    
-     
+        }
+    }
+
+
     private final class GetParameterNamesPrivilegedAction
-            implements PrivilegedAction {
-        
-        public Object run() {          
+            implements PrivilegedAction<Enumeration<String>> {
+
+        @Override
+        public Enumeration<String> run() {
             return request.getParameterNames();
-        }           
-    } 
-    
-    
+        }
+    }
+
+
     private final class GetParameterValuePrivilegedAction
-            implements PrivilegedAction {
+            implements PrivilegedAction<String[]> {
 
         public String name;
 
-        public GetParameterValuePrivilegedAction(String name){
+        GetParameterValuePrivilegedAction(String name){
             this.name = name;
         }
 
-        public Object run() {       
+        @Override
+        public String[] run() {
             return request.getParameterValues(name);
-        }           
-    }    
-  
-    
+        }
+    }
+
+
     private final class GetCookiesPrivilegedAction
-            implements PrivilegedAction {
-        
-        public Object run() {       
+            implements PrivilegedAction<Cookie[]> {
+
+        @Override
+        public Cookie[] run() {
             return request.getCookies();
-        }           
-    }      
-    
-    
+        }
+    }
+
+
     private final class GetCharacterEncodingPrivilegedAction
-            implements PrivilegedAction {
-        
-        public Object run() {       
+            implements PrivilegedAction<String> {
+
+        @Override
+        public String run() {
             return request.getCharacterEncoding();
-        }           
-    }   
-        
-    
+        }
+    }
+
+
     private final class GetHeadersPrivilegedAction
-            implements PrivilegedAction {
+            implements PrivilegedAction<Enumeration<String>> {
 
-        private String name;
+        private final String name;
 
-        public GetHeadersPrivilegedAction(String name){
+        GetHeadersPrivilegedAction(String name){
             this.name = name;
         }
-        
-        public Object run() {       
+
+        @Override
+        public Enumeration<String> run() {
             return request.getHeaders(name);
-        }           
-    }    
-        
-    
+        }
+    }
+
+
     private final class GetHeaderNamesPrivilegedAction
-            implements PrivilegedAction {
+            implements PrivilegedAction<Enumeration<String>> {
 
-        public Object run() {       
+        @Override
+        public Enumeration<String> run() {
             return request.getHeaderNames();
-        }           
-    }  
-            
-    
+        }
+    }
+
+
     private final class GetLocalePrivilegedAction
-            implements PrivilegedAction {
+            implements PrivilegedAction<Locale> {
 
-        public Object run() {       
+        @Override
+        public Locale run() {
             return request.getLocale();
-        }           
-    }    
-            
-    
+        }
+    }
+
+
     private final class GetLocalesPrivilegedAction
-            implements PrivilegedAction {
+            implements PrivilegedAction<Enumeration<Locale>> {
 
-        public Object run() {       
+        @Override
+        public Enumeration<Locale> run() {
             return request.getLocales();
-        }           
-    }    
-    
-    private final class GetSessionPrivilegedAction
-            implements PrivilegedAction {
+        }
+    }
 
-        private boolean create;
-        
-        public GetSessionPrivilegedAction(boolean create){
+    private final class GetSessionPrivilegedAction
+            implements PrivilegedAction<HttpSession> {
+
+        private final boolean create;
+
+        GetSessionPrivilegedAction(boolean create){
             this.create = create;
         }
-                
-        public Object run() {  
+
+        @Override
+        public HttpSession run() {
             return request.getSession(create);
-        }           
-    }
-
-    // ----------------------------------------------------------- Constructors
-
-
-    /**
-     * Construct a wrapper for the specified request.
-     *
-     * @param request The request to be wrapped
-     */
-    public RequestFacade(Request request) {
-
-        this.request = request;
-
+        }
     }
 
 
-    // ----------------------------------------------------- Instance Variables
+    private static final StringManager sm = StringManager.getManager(RequestFacade.class);
+
 
 
     /**
@@ -224,13 +227,13 @@ public class RequestFacade implements HttpServletRequest {
 
 
     /**
-     * The string manager for this package.
+     * Construct a wrapper for the specified request.
+     *
+     * @param request The request to be wrapped
      */
-    protected static StringManager sm =
-        StringManager.getManager(Constants.Package);
-
-
-    // --------------------------------------------------------- Public Methods
+    public RequestFacade(Request request) {
+        this.request = request;
+    }
 
 
     /**
@@ -240,10 +243,11 @@ public class RequestFacade implements HttpServletRequest {
         request = null;
     }
 
-    
+
     /**
      * Prevent cloning the facade.
      */
+    @Override
     protected Object clone()
         throws CloneNotSupportedException {
         throw new CloneNotSupportedException();
@@ -252,104 +256,73 @@ public class RequestFacade implements HttpServletRequest {
 
     // ------------------------------------------------- ServletRequest Methods
 
-
+    @Override
     public Object getAttribute(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getAttribute(name);
     }
 
 
-    public Enumeration getAttributeNames() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+    @Override
+    public Enumeration<String> getAttributeNames() {
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (Enumeration)AccessController.doPrivileged(
-                new GetAttributePrivilegedAction());        
+            return AccessController.doPrivileged(
+                new GetAttributePrivilegedAction());
         } else {
             return request.getAttributeNames();
         }
     }
 
 
+    @Override
     public String getCharacterEncoding() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (String)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetCharacterEncodingPrivilegedAction());
         } else {
             return request.getCharacterEncoding();
-        }         
+        }
     }
 
 
-    public void setCharacterEncoding(String env)
-            throws java.io.UnsupportedEncodingException {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+    @Override
+    public void setCharacterEncoding(String env) throws java.io.UnsupportedEncodingException {
+        checkFacade();
         request.setCharacterEncoding(env);
     }
 
 
+    @Override
     public int getContentLength() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getContentLength();
     }
 
 
+    @Override
     public String getContentType() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getContentType();
     }
 
 
+    @Override
     public ServletInputStream getInputStream() throws IOException {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getInputStream();
     }
 
 
+    @Override
     public String getParameter(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (String)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetParameterPrivilegedAction(name));
         } else {
             return request.getParameter(name);
@@ -357,15 +330,12 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    public Enumeration getParameterNames() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+    @Override
+    public Enumeration<String> getParameterNames() {
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (Enumeration)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetParameterNamesPrivilegedAction());
         } else {
             return request.getParameterNames();
@@ -373,24 +343,21 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
+    @Override
     public String[] getParameterValues(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+        checkFacade();
 
         String[] ret = null;
 
         /*
          * Clone the returned array only if there is a security manager
-         * in place, so that performance won't suffer in the nonsecure case
+         * in place, so that performance won't suffer in the non-secure case
          */
         if (SecurityUtil.isPackageProtectionEnabled()){
-            ret = (String[]) AccessController.doPrivileged(
+            ret = AccessController.doPrivileged(
                 new GetParameterValuePrivilegedAction(name));
             if (ret != null) {
-                ret = (String[]) ret.clone();
+                ret = ret.clone();
             }
         } else {
             ret = request.getParameterValues(name);
@@ -400,179 +367,128 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
-    public Map getParameterMap() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+    @Override
+    public Map<String,String[]> getParameterMap() {
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (Map)AccessController.doPrivileged(
-                new GetParameterMapPrivilegedAction());        
+            return AccessController.doPrivileged(
+                new GetParameterMapPrivilegedAction());
         } else {
             return request.getParameterMap();
         }
     }
 
 
+    @Override
     public String getProtocol() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getProtocol();
     }
 
 
+    @Override
     public String getScheme() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getScheme();
     }
 
 
+    @Override
     public String getServerName() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getServerName();
     }
 
 
+    @Override
     public int getServerPort() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getServerPort();
     }
 
 
+    @Override
     public BufferedReader getReader() throws IOException {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getReader();
     }
 
 
+    @Override
     public String getRemoteAddr() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getRemoteAddr();
     }
 
 
+    @Override
     public String getRemoteHost() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getRemoteHost();
     }
 
 
+    @Override
     public void setAttribute(String name, Object o) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         request.setAttribute(name, o);
     }
 
 
+    @Override
     public void removeAttribute(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         request.removeAttribute(name);
     }
 
 
+    @Override
     public Locale getLocale() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (Locale)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetLocalePrivilegedAction());
         } else {
             return request.getLocale();
-        }        
+        }
     }
 
 
-    public Enumeration getLocales() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+    @Override
+    public Enumeration<Locale> getLocales() {
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (Enumeration)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetLocalesPrivilegedAction());
         } else {
             return request.getLocales();
-        }        
+        }
     }
 
 
+    @Override
     public boolean isSecure() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.isSecure();
     }
 
 
+    @Override
     public RequestDispatcher getRequestDispatcher(String path) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (RequestDispatcher)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetRequestDispatcherPrivilegedAction(path));
         } else {
             return request.getRequestDispatcher(path);
         }
     }
 
+    @Override
     public String getRealPath(String path) {
 
         if (request == null) {
@@ -584,35 +500,28 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
+    @Override
     public String getAuthType() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getAuthType();
     }
 
 
+    @Override
     public Cookie[] getCookies() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+        checkFacade();
 
         Cookie[] ret = null;
 
         /*
          * Clone the returned array only if there is a security manager
-         * in place, so that performance won't suffer in the nonsecure case
+         * in place, so that performance won't suffer in the non-secure case
          */
         if (SecurityUtil.isPackageProtectionEnabled()){
-            ret = (Cookie[])AccessController.doPrivileged(
+            ret = AccessController.doPrivileged(
                 new GetCookiesPrivilegedAction());
             if (ret != null) {
-                ret = (Cookie[]) ret.clone();
+                ret = ret.clone();
             }
         } else {
             ret = request.getCookies();
@@ -622,262 +531,183 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
+    @Override
     public long getDateHeader(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getDateHeader(name);
     }
 
 
+    @Override
     public String getHeader(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getHeader(name);
     }
 
 
-    public Enumeration getHeaders(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+    @Override
+    public Enumeration<String> getHeaders(String name) {
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (Enumeration)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetHeadersPrivilegedAction(name));
         } else {
             return request.getHeaders(name);
-        }         
+        }
     }
 
 
-    public Enumeration getHeaderNames() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+    @Override
+    public Enumeration<String> getHeaderNames() {
+        checkFacade();
 
         if (Globals.IS_SECURITY_ENABLED){
-            return (Enumeration)AccessController.doPrivileged(
+            return AccessController.doPrivileged(
                 new GetHeaderNamesPrivilegedAction());
         } else {
             return request.getHeaderNames();
-        }             
+        }
     }
 
 
+    @Override
     public int getIntHeader(String name) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getIntHeader(name);
     }
 
 
+    @Override
     public String getMethod() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getMethod();
     }
 
 
+    @Override
     public String getPathInfo() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getPathInfo();
     }
 
 
+    @Override
     public String getPathTranslated() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getPathTranslated();
     }
 
 
+    @Override
     public String getContextPath() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getContextPath();
     }
 
 
+    @Override
     public String getQueryString() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getQueryString();
     }
 
 
+    @Override
     public String getRemoteUser() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getRemoteUser();
     }
 
 
+    @Override
     public boolean isUserInRole(String role) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.isUserInRole(role);
     }
 
 
+    @Override
     public java.security.Principal getUserPrincipal() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getUserPrincipal();
     }
 
 
+    @Override
     public String getRequestedSessionId() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getRequestedSessionId();
     }
 
 
+    @Override
     public String getRequestURI() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getRequestURI();
     }
 
 
+    @Override
     public StringBuffer getRequestURL() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getRequestURL();
     }
 
 
+    @Override
     public String getServletPath() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getServletPath();
     }
 
 
+    @Override
     public HttpSession getSession(boolean create) {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
+        checkFacade();
 
         if (SecurityUtil.isPackageProtectionEnabled()){
-            return (HttpSession)AccessController.
+            return AccessController.
                 doPrivileged(new GetSessionPrivilegedAction(create));
         } else {
             return request.getSession(create);
         }
     }
 
+    @Override
     public HttpSession getSession() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return getSession(true);
     }
 
+    @Override
+    public String changeSessionId() {
+        checkFacade();
+        return request.changeSessionId();
+    }
 
+    @Override
     public boolean isRequestedSessionIdValid() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.isRequestedSessionIdValid();
     }
 
 
+    @Override
     public boolean isRequestedSessionIdFromCookie() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.isRequestedSessionIdFromCookie();
     }
 
 
+    @Override
     public boolean isRequestedSessionIdFromURL() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.isRequestedSessionIdFromURL();
     }
 
 
+    @Override
     public boolean isRequestedSessionIdFromUrl() {
 
         if (request == null) {
@@ -889,50 +719,157 @@ public class RequestFacade implements HttpServletRequest {
     }
 
 
+    @Override
     public String getLocalAddr() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getLocalAddr();
     }
 
 
+    @Override
     public String getLocalName() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getLocalName();
     }
 
 
+    @Override
     public int getLocalPort() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getLocalPort();
     }
 
 
+    @Override
     public int getRemotePort() {
-
-        if (request == null) {
-            throw new IllegalStateException(
-                            sm.getString("requestFacade.nullRequest"));
-        }
-
+        checkFacade();
         return request.getRemotePort();
     }
 
+
+    @Override
+    public ServletContext getServletContext() {
+        checkFacade();
+        return request.getServletContext();
+    }
+
+
+    @Override
+    public AsyncContext startAsync() throws IllegalStateException {
+        checkFacade();
+        return request.startAsync();
+    }
+
+
+    @Override
+    public AsyncContext startAsync(ServletRequest request, ServletResponse response) throws IllegalStateException {
+        checkFacade();
+        return this.request.startAsync(request, response);
+    }
+
+
+    @Override
+    public boolean isAsyncStarted() {
+        checkFacade();
+        return request.isAsyncStarted();
+    }
+
+
+    @Override
+    public boolean isAsyncSupported() {
+        checkFacade();
+        return request.isAsyncSupported();
+    }
+
+
+    @Override
+    public AsyncContext getAsyncContext() {
+        checkFacade();
+        return request.getAsyncContext();
+    }
+
+
+    @Override
+    public DispatcherType getDispatcherType() {
+        checkFacade();
+        return request.getDispatcherType();
+    }
+
+
+    @Override
+    public boolean authenticate(HttpServletResponse response) throws IOException, ServletException {
+        checkFacade();
+        return request.authenticate(response);
+    }
+
+    @Override
+    public void login(String username, String password) throws ServletException {
+        checkFacade();
+        request.login(username, password);
+    }
+
+    @Override
+    public void logout() throws ServletException {
+        checkFacade();
+        request.logout();
+    }
+
+    @Override
+    public Collection<Part> getParts() throws IllegalStateException, IOException, ServletException {
+        checkFacade();
+        return request.getParts();
+    }
+
+
+    @Override
+    public Part getPart(String name) throws IllegalStateException, IOException, ServletException {
+        checkFacade();
+        return request.getPart(name);
+    }
+
+
     public boolean getAllowTrace() {
+        checkFacade();
         return request.getConnector().getAllowTrace();
     }
+
+
+    @Override
+    public long getContentLengthLong() {
+        checkFacade();
+        return request.getContentLengthLong();
+    }
+
+
+    @Override
+    public <T extends HttpUpgradeHandler> T upgrade(
+            Class<T> httpUpgradeHandlerClass) throws java.io.IOException, ServletException {
+        checkFacade();
+        return request.upgrade(httpUpgradeHandlerClass);
+    }
+
+
+    public ApplicationMappingImpl getHttpServletMapping() {
+        checkFacade();
+        return request.getHttpServletMapping();
+    }
+
+
+    public ApplicationPushBuilder newPushBuilder(javax.servlet.http.HttpServletRequest request) {
+        checkFacade();
+        return this.request.newPushBuilder(request);
+    }
+
+
+    public ApplicationPushBuilder newPushBuilder() {
+        checkFacade();
+        return request.newPushBuilder();
+    }
+
+
+    private void checkFacade() {
+        if (request == null) {
+            throw new IllegalStateException(sm.getString("requestFacade.nullRequest"));
+        }
+    }
 }
