@@ -975,7 +975,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         private final InputStream is;
 
 
-        public TestInput(InputStream is) {
+        TestInput(InputStream is) {
             this.is = is;
         }
 
@@ -1206,11 +1206,11 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         @Override
         public void onSwallowedUnknownFrame(int streamId, int frameTypeId, int flags, int size) {
             trace.append(streamId);
-            trace.append(",");
+            trace.append(',');
             trace.append(frameTypeId);
-            trace.append(",");
+            trace.append(',');
             trace.append(flags);
-            trace.append(",");
+            trace.append(',');
             trace.append(size);
             trace.append("\n");
         }
@@ -1269,6 +1269,18 @@ public abstract class Http2TestBase extends TomcatBaseTest {
     }
 
 
+    public static class NoContentServlet extends HttpServlet {
+
+        private static final long serialVersionUID = 1L;
+
+        @Override
+        protected void doGet(HttpServletRequest req, HttpServletResponse resp)
+                throws ServletException, IOException {
+            resp.setStatus(HttpServletResponse.SC_NO_CONTENT);
+        }
+    }
+
+
     protected static class SimpleServlet extends HttpServlet {
 
         private static final long serialVersionUID = 1L;
@@ -1450,7 +1462,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         private final int setting;
         private final long value;
 
-        public SettingValue(int setting, long value) {
+        SettingValue(int setting, long value) {
             this.setting = setting;
             this.value = value;
         }
@@ -1469,7 +1481,7 @@ public abstract class Http2TestBase extends TomcatBaseTest {
         private final String name;
         private final String value;
 
-        public Header(String name, String value) {
+        Header(String name, String value) {
             this.name = name;
             this.value = value;
         }
